summaryrefslogtreecommitdiffstats
path: root/tdecore/tests/kconfigtestgui.h
diff options
context:
space:
mode:
Diffstat (limited to 'tdecore/tests/kconfigtestgui.h')
-rw-r--r--tdecore/tests/kconfigtestgui.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/tdecore/tests/kconfigtestgui.h b/tdecore/tests/kconfigtestgui.h
index 7655c8142..f5bbfd659 100644
--- a/tdecore/tests/kconfigtestgui.h
+++ b/tdecore/tests/kconfigtestgui.h
@@ -36,15 +36,15 @@
#include <kconfig.h>
//
// KConfigTestView contains lots of Qt widgets.
//
-class KConfigTestView : public TQDialog
+class TDEConfigTestView : public TQDialog
{
Q_OBJECT
public:
- KConfigTestView( TQWidget *parent=0, const char *name=0 );
- ~KConfigTestView();
+ TDEConfigTestView( TQWidget *parent=0, const char *name=0 );
+ ~TDEConfigTestView();
private slots:
void appConfigEditReturnPressed();
@@ -64,7 +64,7 @@ private:
TQLabel* pInfoLabel1, *pInfoLabel2;
TQPushButton* pQuitButton;
- KConfig* pConfig;
+ TDEConfig* pConfig;
TQFile* pFile;
TQTextStream* pStream;
};
@@ -36,15 +36,15 @@
#include <kconfig.h>
//
-// KConfigTestView contains lots of Qt widgets.
+// TDEConfigTestView contains lots of Qt widgets.
//